=====
konch
=====


**konch** is a CLI and configuration utility for the Python shell.

Simple, productive, and fun
===========================

- **Automatically import** any object upon startup
- **Simple**, per-project configuration in a single file (it's just Python code)
- **No dependencies**
- Uses **IPython** and **BPython** if available, and falls back to built-in interpreter
- Can have multiple configurations per project using **named configs**

.. image:: https://dl.dropboxusercontent.com/u/1693233/github/konch-030-demo-optim.gif
    :alt: Demo
    :target: http://konch.readthedocs.org


`http://konch.readthedocs.org <http://konch.readthedocs.org>`_
==============================================================

